@@ -7,7 +7,4 @@ class Discoverable(SSDPDiscoverable):
 
     def get_entries(self):
         """Get all the LionBox uPnP entries."""
-        return self.find_by_device_description({
-            "friendlyName": "little_creator",
-            "modelName": "little_lion_gateway"
-        })
+        return self.find_by_st("urn:schemas-upnp-org:service:ConnectionManager:1")
